#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
from jinja2 import Environment, FileSystemLoader
from jinja2_markdown import MarkdownExtension
import json
import codecs

PATH = os.path.dirname(os.path.abspath(__file__))

#languages = [False,'zh','ja','ko','en','de']
languages = [False,'zh','zh_big5','en','de']

def render_template(jinja_env, template_filename, language):
    print("Language: "+language)
    try:
        json_content = json.load(fp=open("lang/"+language+".json"))#,encoding="utf-8")
    except Exception as e:
        print("Error rendering language: "+language)
        print(e)
        return None 
    else:
        return jinja_env.get_template(template_filename).render(json_content)

def create_index_html(jinja_env):
    for lang in languages:
        fname = "index"
        if lang:
            fname+='_'
            fname+=lang
        else:
            lang='en'
        fname+=".html"
        # rendering
        with codecs.open(fname, 'w', "utf-8-sig") as f:
            html = render_template(jinja_env, 'index.tpl',lang)
            if(html is not None):
                f.write(html)

def create_news_html(jinja_env):
    for lang in languages:
        fname = "news"
        if lang:
            fname+='_'
            fname+=lang
        else:
            lang='en'
        fname+=".rss"
        # rendering
        with codecs.open(fname, 'w', "utf-8-sig") as f:
            html = render_template(jinja_env, 'news.tpl',lang)
            if(html is not None):
                f.write(html)

def main():
    jinja_env = Environment(
        autoescape = False,
        loader=FileSystemLoader(os.path.join(PATH, 'templates')),
        trim_blocks = False,
        extensions=['jinja2_markdown.MarkdownExtension']
    )
    jinja_env.add_extension(MarkdownExtension)
    create_index_html(jinja_env)
    create_news_html(jinja_env)

########################################

if __name__ == "__main__":
    main()


#ginger index.tpl lang/en.json | grep -v "^null$" > index.html
#ginger news.tpl  lang/en.json | grep -v "^null$" > news.rss
#ginger img/LSA-whitepaper.tpl lang/en.json | grep -v "^null$" > img/LSA-whitepaper.svg

#for lang in zh ja ko en de
#do  
#  ginger index.tpl lang/$lang.json | grep -v "^null$" > index_$lang.html
#  ginger news.tpl  lang/$lang.json | grep -v "^null$" > news_$lang.rss
#ginger img/LSA-whitepaper.tpl lang/$lang.json | grep -v "^null$" > img/LSA-whitepaper_$lang.svg
#done
